==> 1.0.2.tar.gz: lib/api/apple_api.dart <==
part of forestvpn_api.api;



class AppleApi {
  final ApiClient apiClient;

  AppleApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Apple Store Server to Server Notifications
  ///
  /// 
  Future appleStoreServerNotification(AppleStoreServerNotification notification) async {
    Object postBody = notification;

    // verify required params are set
    if(notification == null) {
     throw new ApiException(400, "Missing required param: notification");
    }

    // create path and map variables
    String path = "/apple/ssn/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = [];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          ;
    } else {
      return ;
    }
  }
  /// Verify receipt
  ///
  /// 
  Future<AppleStoreUnifiedReceipt> verifyReceipt(AppleVerifyReceiptRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw new ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/apple/verify-receipt/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'AppleStoreUnifiedReceipt') as AppleStoreUnifiedReceipt ;
    } else {
      return null;
    }
  }
}

==> 1.0.3.tar.gz: lib/api/apple_api.dart <==
part of forestvpn_api.api;



class AppleApi {
  final ApiClient apiClient;

  AppleApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Apple Store Server to Server Notifications with HTTP info returned
  ///
  /// 
  Future appleStoreServerNotificationWithHttpInfo(AppleStoreServerNotification notification) async {
    Object postBody = notification;

    // verify required params are set
    if(notification == null) {
     throw ApiException(400, "Missing required param: notification");
    }

    // create path and map variables
    String path = "/apple/ssn/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Apple Store Server to Server Notifications
  ///
  /// 
  Future appleStoreServerNotification(AppleStoreServerNotification notification) async {
    Response response = await appleStoreServerNotificationWithHttpInfo(notification);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Verify receipt with HTTP info returned
  ///
  /// 
  Future<Response> verifyReceiptWithHttpInfo(AppleVerifyReceiptRequest request) async {
    Object postBody = request;

    // verify required params are set
    if(request == null) {
     throw ApiException(400, "Missing required param: request");
    }

    // create path and map variables
    String path = "/apple/verify-receipt/".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = ["Bearer"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);
    return response;
  }

  /// Verify receipt
  ///
  /// 
  Future<AppleStoreUnifiedReceipt> verifyReceipt(AppleVerifyReceiptRequest request) async {
    Response response = await verifyReceiptWithHttpInfo(request);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'AppleStoreUnifiedReceipt') as AppleStoreUnifiedReceipt;
    } else {
      return null;
    }
  }

}
